@@ -36,8 +36,8 @@ r_plus <- function(vars, add_zero = FALSE) {
 #' are each intended to be simple variable names or column names (or .). They are not
 #' intended to specify
 #' interactions, I()-terms, transforms, general experessions or other complex formula terms.
-#' Essentially the same effect as \code{\link[stats]{reformulate}}, but trying to avoid the
-#' \code{paste} currently in \code{\link[stats]{reformulate}} by calling \code{\link[stats]{update.formula}}
+#' Essentially the same effect as \code{\link[stats:delete.response]{reformulate}}, but trying to avoid the
+#' \code{paste} currently in \code{\link[stats:delete.response]{reformulate}} by calling \code{\link[stats]{update.formula}}
 #' (which appears to work over terms).
 #' Another reasonable way to do this is just \code{paste(outcome, paste(variables, collapse = " + "), sep = " ~ ")}.
 #'
@@ -55,9 +55,10 @@ r_plus <- function(vars, add_zero = FALSE) {
 #' @param outcome_comparator one of "==", "!=", ">=", "<=", ">", "<", only use of outcome_target is not NULL.
 #' @param env environment to use in formula (unless extra_values is non empty, then this is a parent environemnt).
 #' @param extra_values if not empty extra values to be added to a new formula environment containing env.
+#' @param as_character if TRUE return formula as a character string.
 #' @return a formula object
 #'
-#' @seealso \code{\link[stats]{reformulate}}, \code{\link[stats]{update.formula}}
+#' @seealso \code{\link[stats:delete.response]{reformulate}}, \code{\link[stats]{update.formula}}
 #'
 #' @examples
 #'
@@ -79,7 +80,8 @@ mk_formula <- function(outcome, variables,
                        outcome_target = NULL,
                        outcome_comparator = "==",
                        env = baseenv(),
-                       extra_values = NULL) {
+                       extra_values = NULL,
+                       as_character = FALSE) {
   force(env)
   wrapr::stop_if_dot_args(substitute(list(...)), "wrapr::mk_formula")
   if((!is.character(outcome)) || (length(outcome)!=1)) {
@@ -138,5 +140,8 @@ mk_formula <- function(outcome, variables,
     list(outcome_expr,
          rhs_expr),
     envir = env)
+  if(as_character) {
+    f <- paste(trimws(format(f)), collapse = ' ')
+  }
   f
 }
